<?php
	//This file contains all functions used by multiple pages on the MRS
	
	//Function for getting the song list
	function get_song_list()
	{
		if(file_exists("backend/songlist.txt") && file_get_contents("backend/songlist.txt") != "")
		{
			return explode("\r\n",file_get_contents("backend/songlist.txt"));
		}
		return array();
	}
	//Function for writing log message to system log
	function write_log($ip,$time,$message)
	{
		$fh=fopen("log/" . date("Ymd") . ".txt",'a') or die("Failed to open file \"log/" . date("Ymd") . ".txt\" in append mode. It should now be microwaved.");
		fwrite($fh,$ip . " at " . $time . ": " . stripcslashes($message) . "\r\n");
		fclose($fh);
	}
	//Function for getting alternative session store information
	function alt_ses_store()
	{
		if(file_exists("backend/altsesstore.txt") && file_get_contents("backend/altsesstore.txt") == "yes" && file_exists("backend/altsesstorepath.txt") && file_exists(file_get_contents("backend/altsesstorepath.txt")) && is_readable(file_get_contents("backend/altsesstorepath.txt")) && is_writable(file_get_contents("backend/altsesstorepath.txt")))
		{
			return file_get_contents("backend/altsesstorepath.txt");
		}
		return false;
	}
	//Function for retrieving system name
	function system_name()
	{
		if(file_exists("backend/name.txt") && file_get_contents("backend/name.txt") != "")
		{
			return file_get_contents("backend/name.txt") . " ";
		}
		return "";
	}
	//Function for getting posting status
	function is_system_enabled()
	{
		if(file_exists("backend/posting.txt") && file_get_contents("backend/posting.txt") == "yes")
		{
			return true;
		}
		return false;
	}
	//Function for getting logging status
	function is_logging_enabled()
	{
		if(file_exists("backend/logging.txt") && file_get_contents("backend/logging.txt") == "yes")
		{
			return true;
		}
		return false;
	}
	//Function for getting system overload level
	function get_system_overload()
	{
		if(file_exists("backend/limit.txt") && file_get_contents("backend/limit.txt") != "")
		{
			return file_get_contents("backend/limit.txt");
		}
		return 0;
	}
	//Function for determining if the system is in overload mode
	function system_in_overload()
	{
		//Get the overload level
		$olevel=get_system_overload();
		if($olevel > 0)
		{
			//System has an overload point, get number of open requests
			$openreqs=get_open_reqs();
			if($openreqs >= $olevel)
			{
				//System is in overload mode
				return true;
			}
		}
		return false;
	}
	//Function for getting the system IP banlist
	function get_IP_banlist()
	{
		if(file_exists("ban/ip.txt") && file_get_contents("ban/ip.txt") != "")
		{
			return explode("\r\n",file_get_contents("ban/ip.txt"));
		}
		return array();
	}
	//Function for getting the system username banlist
	function get_uname_banlist()
	{
		if(file_exists("ban/uname.txt") && file_get_contents("ban/uname.txt") != "")
		{
			return explode("\r\n",file_get_contents("ban/uname.txt"));
		}
		return array();
	}
	//Function for getting all requests
	function get_all_requests()
	{
		return glob("posts/*.txt");
	}
	//Function for getting a specific request
	function get_request($id)
	{
		if(!file_exists("posts/" . $id . ".txt"))
		{
			trigger_error("ID passed to get_request does not correspond to a valid request",E_USER_WARNING);
			return array(0,"Error","127.0.0.1","01/01/1970 12:00 AM","This request could not be displayed due to an internal error",3,"","Please microwave the system.");
		}
		return get_post_contents("posts/" . $id . ".txt");
	}
	//Function for getting post contents (post contents format: [id,name,ip,date,request,status,admincomment,usercomment])
	function get_post_contents($post)
	{
		//Set up initial format
		$content=array(0,"Error","127.0.0.1","01/01/1970 12:00 AM","This request could not be displayed due to an internal error",3,"","Please microwave the system.");
		if(!file_exists($post))
		{
			//Could not read post, throw error
			trigger_error("File passed to get_post_contents does not exist",E_USER_WARNING);
		}
		else
		{
			//Read and split file
			$contents=explode("\r\n",base64_decode(file_get_contents($post)));
			$contents[5]=explode("|",$contents[5]);
			//Insert contents into formatted array
			$content[0]=$contents[0];
			$content[1]=$contents[1];
			$content[2]=$contents[2];
			$content[3]=$contents[3];
			$content[4]=$contents[4];
			$content[5]=$contents[5][0];
			$content[6]=$contents[5][1];
			if(isset($contents[6]))
			{
				$content[7]=$contents[6];
			}
			else
			{
				$content[7]="None";
			}
		}
		//Return the formatted array
		return $content;
	}
	//Function for getting requests of a specific status
	function get_specific_reqs($reqlvl)
	{
		//If requests levels is not an array, make it an array of just the request level
		if(!is_array($reqlvl))
		{
			$reqlvl=array($reqlvl);
		}
		$count=0;
		//Get all posts
		$posts=get_all_requests();
		//Loop through posts
		foreach($posts as $post)
		{
			//Get contents
			$content=get_post_contents($post);
			//If post is either unseen or in queue, increment counter
			if(in_array($content[5],$reqlvl))
			{
				$count++;
			}
		}
		//Return the counter
		return $count;
	}
	//Function for getting requests of a specific status, and returning a list of them
	function get_specific_reqs_return($reqlvl)
	{
		//If requests levels is not an array, make it an array of just the request level
		if(!is_array($reqlvl))
		{
			$reqlvl=array($reqlvl);
		}
		$reqs=array();
		//Get all posts
		$posts=get_all_requests();
		//Loop through posts
		foreach($posts as $post)
		{
			//Get contents
			$content=get_post_contents($post);
			//If post is either unseen or in queue, add the filename to the list
			if(in_array($content[5],$reqlvl))
			{
				$reqs[]=$post;
			}
		}
		//Return the list
		return $reqs;
	}
	//Function for getting all open requests
	function get_open_reqs()
	{
		return get_specific_reqs(array(0,2));
	}
	//Function for setting the system timezone
	function set_timezone()
	{
		if(file_exists("backend/timezone.txt"))
		{
			date_default_timezone_set(file_get_contents("backend/timezone.txt"));
		}
		else
		{
			date_default_timezone_set("America/Toronto");
		}
	}
	//Function to check if post exists
	function does_post_exist($id)
	{
		if(file_exists("posts/$id.txt"))
		{
			return true;
		}
		return false;
	}
	//Function for writing a request
	function write_request($id,$poster,$ip,$date,$request,$status,$response,$comment)
	{
		$content="$id\r\n$poster\r\n$ip\r\n$date\r\n" . stripcslashes($request) . "\r\n$status|" . stripcslashes($response) . "\r\n" . stripcslashes($comment) . "\r\n";
		$fh=fopen("posts/$id.txt",'w');
		if(!$fh)
		{
			trigger_error("Could not open post $id for writing",E_USER_WARNING);
			return false;
		}
		fwrite($fh,base64_encode($content));
		fclose($fh);
		return true;
	}
?>